@@ -8,6 +8,7 @@ use vars qw( @ISA @EXPORT @EXPORT_OK $VERSION );
 
 use HTML::Template;
 use HTML::FillInForm;
+use HTML::Pager;
 
 @ISA = qw( Exporter AutoLoader );
 
@@ -19,7 +20,11 @@ our @EXPORT_OK = qw(
     log_directive	
 );
 
-our $VERSION = '0.12_2';
+our $VERSION = '0.10';
+
+use Data::Dumper;
+
+my ( $internal_data );
 
 sub import
 {
@@ -36,8 +41,8 @@ sub _register_runmodes
     #warn "CGI::Application::Plugin::BREAD::register_runmodes() called!";
     %runmodes = ( 'start' => \&_start );
     $tables = {};
-    if ( $self->{'BREAD'}->{'classes'} ) {
-        foreach my $cdbi_class ( @{$self->{'BREAD'}->{'classes'}} ) {
+    if ( $internal_data->{'classes'} ) {
+        foreach my $cdbi_class ( @{$internal_data->{'classes'}} ) {
             my $table = $cdbi_class->table;
             $runmodes{ "browse_$table" }            = \&_browse;
             $runmodes{ "read_$table" }              = \&_read;
@@ -51,11 +56,12 @@ sub _register_runmodes
     } else {
         die "We don't have any db classes!  Did you set any up with the bread_db() method?";
     }
-    $self->{'BREAD'}->{'tables'} = $tables;
+    $internal_data->{'tables'} = $tables;
+    #die Dumper( \%ENV );
     $uri = $ENV{'SCRIPT_URI'};
     # take off any tailing parameters...
     #$uri =~ s/\?.+//;
-    $self->{'BREAD'}->{'uri'} = $uri;
+    $internal_data->{'uri'} = $uri;
     
     $self->run_modes( %runmodes );
 }
@@ -70,7 +76,7 @@ sub bread_db
     # check parameter type ... it's either an arrayref or a ::Loader ref
     $classes = [];
     if ( ref( $parameter ) eq 'ARRAY' ) {
-        $self->{'BREAD'}->{'cdbi_type'} = 'classes';
+        $internal_data->{'cdbi_type'} = 'classes';
         foreach my $cdbi_class ( @$parameter ) {
             # check to see if it's loaded already
             unless ( $cdbi_class:: ) {
@@ -86,7 +92,7 @@ sub bread_db
             push @$classes, $cdbi_class;
         }
     } elsif ( ref( $parameter ) =~ /^Class::DBI::Loader/ ) {
-        $self->{'BREAD'}->{'cdbi_type'} = 'loader';
+        $internal_data->{'cdbi_type'} = 'loader';
         foreach my $class ( $parameter->classes ) {
             push @$classes, $class;
         }
@@ -94,14 +100,14 @@ sub bread_db
         my $ref = ref( $parameter );
         die "CGI::Application::Plugin::BREAD::bread_db(): Invalid parameter\nParameter must either be an array reference of Class::DBI classes or a Class::DBI::Loader object\nYou gave me a $ref object.";
     }
-    $self->{'BREAD'}->{'classes'} = $classes;
+    $internal_data->{'classes'} = $classes;
 }
 
 sub browse_page_size
 {
-    my ( $self, $size ) = @_;
+    my ( undef, $size ) = @_;
     if ( $size =~ /^\d+$/ && $size > 0 ) {
-        $self->{'BREAD'}->{'page_size'} = $size;
+        $internal_data->{'page_size'} = $size;
     } else {
         warn "CGI::Application::Plugin::BREAD::browse_page_size(): Invalid page_size ($size) - must be a positive decimal.";
     }
@@ -128,13 +134,13 @@ sub _start
     $self = shift;
     
     $table_ar = [];
-    $table_hr = $self->{'BREAD'}->{'tables'};
+    $table_hr = $internal_data->{'tables'};
     while( my ( $table, undef ) = each %$table_hr ) {
         push @$table_ar, {
                 'table' => $table,
             };
     }
-    $uri = $self->{'BREAD'}->{'uri'};
+    $uri = $internal_data->{'uri'};
     
     $template_html = <<_EOF_;
 <html>
@@ -165,15 +171,15 @@ sub _browse
     $runmode = $self->get_current_runmode();
     ( $table ) = $runmode =~ /^browse_(.+)$/;
     
-    $class = $self->{'BREAD'}->{'tables'}->{$table};
-    $self->{'BREAD'}->{'page_size'} = 20 if ! $self->{'BREAD'}->{'page_size'};
+    $class = $internal_data->{'tables'}->{$table};
+    $internal_data->{'page_size'} = 20 if ! $internal_data->{'page_size'};
     
     @columns = $class->columns;
     $colspan = scalar( @columns );
     $objects_iterator = $class->retrieve_all;
     $headers = [];
     $subtemplate = '';
-    $uri = $self->{'BREAD'}->{'uri'};
+    $uri = $internal_data->{'uri'};
     # pull out primary column (if we have it) first...
     if ( my $primary = $class->primary_column ) {
         push @$headers, { 'header' => $primary };
@@ -232,8 +238,8 @@ _EOF_
             'table'     => $table,
             'headers'   => $headers,
             'count'     => $objects_iterator->count,
-            'pagesize'  => $self->{'BREAD'}->{'page_size'},
-            'num_pages' => sprintf( "%d", ($objects_iterator->count/$self->{'BREAD'}->{'page_size'})+1 )
+            'pagesize'  => $internal_data->{'page_size'},
+            'num_pages' => sprintf( "%d", ($objects_iterator->count/$internal_data->{'page_size'})+1 )
         );
     
     $get_data_sub = sub
@@ -256,16 +262,16 @@ _EOF_
             return $records;
         };
     
-    require HTML::Pager;
     $pager = HTML::Pager->new(
             'template'          => $template,
             'query'             => $self->query,
             'rows'              => $objects_iterator->count,
-            'page_size'         => $self->{'BREAD'}->{'page_size'},
+            'page_size'         => $internal_data->{'page_size'},
             'get_data_callback' => $get_data_sub,
             'persist_vars'      => [ 'rm' ],
         );
-   return  $pager->output();
+    $pager->output();
+
 }
 
 sub _read
@@ -283,7 +289,7 @@ sub _edit
 
     $html = _get_add_or_edit_form( $self );
 
-    $class = $self->{'BREAD'}->{'tables'}->{$table};
+    $class = $internal_data->{'tables'}->{$table};
     $obj = $class->retrieve( $self->query->param( 'id' ) );
     %data = ();
     foreach my $column ( sort $class->columns ) {
@@ -313,13 +319,13 @@ sub _delete
     $self = shift;
     $runmode = $self->get_current_runmode();
     ( $table ) = $runmode =~ /^delete_(.+)$/;
-    $class = $self->{'BREAD'}->{'tables'}->{$table};
+    $class = $internal_data->{'tables'}->{$table};
     $obj = $class->retrieve( $self->query->param( 'id' ) );
     
     $obj->delete;
     
     $self->header_type( 'redirect' );
-    $self->header_props( -url => $self->{'BREAD'}->{'uri'} );
+    $self->header_props( -url => $internal_data->{'uri'} );
 }
 
 sub _submit
@@ -329,7 +335,7 @@ sub _submit
     $self = shift;
     $runmode = $self->get_current_runmode();
     ( $mode, $table ) = $runmode =~ /^(add|edit)_(.+)_submit$/;
-    $class = $self->{'BREAD'}->{'tables'}->{$table};
+    $class = $internal_data->{'tables'}->{$table};
     
     $form = $class->as_form( params => $self->query );
     if ( $form->submitted ) {
@@ -344,7 +350,7 @@ sub _submit
     
     # redirecting user back to main page
     $self->header_type( 'redirect' );
-    $self->header_props( -url => $self->{'BREAD'}->{'uri'} );
+    $self->header_props( -url => $internal_data->{'uri'} );
 }
 
 sub _get_add_or_edit_form
@@ -361,7 +367,7 @@ sub _get_add_or_edit_form
 
     $runmode = $self->get_current_runmode();
     ( $mode, $table ) = $runmode =~ /^(add|edit)_(.+)$/;
-    $class = $self->{'BREAD'}->{'tables'}->{$table};
+    $class = $internal_data->{'tables'}->{$table};
     $class->form_builder_defaults( { method => 'post' } );
 
     $form = $class->as_form( params => $self->query )->render;
@@ -393,7 +399,7 @@ __END__
 
 =head1 NAME
 
-CGI::Application::Plugin::BREAD - Plugin for Dynamic Database Management Application
+CGI::Application::Plugin::BREAD
 
 =head2 Description
 
@@ -408,8 +414,7 @@ In your CGI::Application module:
   package MyBREADApp;
 
   use base 'CGI::Application';
-  use CGI::Application::Plugin::BREAD qw( bread_db );
-  use Class::DBI::Loader;
+  use CGI::Application::Plugin::BREAD;
 
   sub setup
   {
@@ -474,18 +479,6 @@ L<CGI::Application>, L<HTML::Template>, L<Template::Toolkit>, L<Petal.pm>, L<DBI
 
 L<http://www.cgi-app.org> CGI::Application Wiki
 
-=head1 DEVELOPMENT
-
-This software is managed with darcs (L<http://www.darcs.net>). You can get the repository here with darcs:
-
-L<http://www.purdy.info/darcs/cap-bread>
-
-Or browse it via the web:
-
-L<http://www.purdy.info/cgi-bin/darcs.cgi/cap-bread/?c=browse>
-
-You can discuss this module on cgi-app@lists.erlbaum.net or #cgiapp on irc.perl.org.
-
 =head1 BUGS
 
 This release is "alpha" - please do not use this in a production
@@ -499,7 +492,6 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=CGI-Application-Plugin-BREAD>
 =head1 AUTHORS
 
 Jason Purdy, <jason@purdy.info>
-Mark Stosberg <mark@summersault.com>
 
 =head1 LICENSE
 
